@@ -10,7 +10,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
@@ -19,18 +19,20 @@
 #ifndef _LVM_LIB_H
 #define _LVM_LIB_H
 
-#include "configure.h"
+#include "device_mapper/all.h"
+#include "base/memory/zalloc.h"
+#include "lib/misc/intl.h"
+#include "lib/misc/util.h"
 
-#define _REENTRANT
-#define _GNU_SOURCE
-#define _FILE_OFFSET_BITS 64
+#ifdef DM
+#  include "libdm/misc/dm-logging.h"
+#else
+#  include "lib/log/lvm-logging.h"
+#  include "lib/misc/lvm-globals.h"
+#  include "lib/misc/lvm-wrappers.h"
+#  include "lib/misc/lvm-maths.h"
+#endif
 
-#include "log.h"
-#include "intl.h"
-#include "lvm-types.h"
-#include "lvm-wrappers.h"
-#include "util.h"
-
-#include <libdevmapper.h>
+#include <unistd.h>
 
 #endif
